// UNION DATA
* Authors note: Here, we calculate union duration up to age 46, and take the nr of unions by age 46. Data has one row per person-year (PY). It includes the union status of PY (unionx1: not in union,married,cohabitig) and the nr of unique accumulated unions by PY (marry_stat, forma_stat). 
local sex men women
foreach gender of local sex {
use shnro year age sex byear unionx1 marry_stat forma_stat using  "$path2`gender'union.dta" if  byear > 1968 & byear < 1973 & age >17 & age < 47, clear

bys shnro: egen uniondur = sum(unionx1>0) // time in any union
bys shnro: egen mardur = sum(unionx1==2) // time in marriage

bys shnro: keep if age == 46
keep shnro uniondur mardur marry_stat forma_stat
compress
save "$path2`gender'unionvar.dta", replace
}









// FERTILITY DATA
* Authors note: Here, we set the population exclusion criterions, and take the cumulated number of births by age 46. Data has one row per person-year (PY). parity_stat denote the nr of cumulated nr of births by PY, kuntaryhm and ptoim1 are used to infer if person is registered in Finland at PY (if not it is due either to death or migration) 
local sex men women
foreach gender of local sex {
use shnro year age byear sex parity_stat kuntaryhm ptoim1 svaltio_k using  "$path2\`gender'fertility.dta" if byear > 1968 & byear < 1973 & age > 17 & age < 48, clear

// generate ever migrated
gen q = (ptoim1 == . & year != 2018)
replace q = 1 if kuntaryhm == . & year == 2018
bys shnro: egen evernotinpop = max(q)
drop q

// drop foreignborn
drop if svaltio_k != 1

// drop if migrated/dead before 46
drop if evernotinpop != 0

// gen age at first birth
gen q = age if parity_stat > 0 
bys shnro: egen afb = min(q)
recode afb . = 0 
drop q

// keeps obs present at age 46, and only these years
keep if age == 46

// keep vars
keep shnro sex parity_stat byear afb

// merge with union dataset
merge 1:1 shnro using "$path2\`gender'unionvar.dta", keep(matched master) nogen

// drop if contradictory union data 
gen wrong1 = 1 if marry_stat == 0 & mardur != 0
gen wrong2 = 1 if mardur == 0 &  marry_stat != 0
gen wrong3 = 1 if forma_stat == 0 & marry_stat != 0 
gen wrong4 = 1 if uniondur == 0 &  mardur != 0
gen wrong5 = 1 if forma_stat == 0 & uniondur != 0 
gen wrong6 = 1 if uniondur == 0 & forma_stat != 0 
egen wrong = rowmax(wrong*) 
ta wrong, m // about (0.12%) individuals has contradictory/potentially contradictory union histories
drop if wrong == 1 
drop wrong*

// save 
save "$path2\`gender'unionfertility_rnr.dta", replace
}

// gather men women in one dataset
append using  "$path2\menunionfertility_rnr.dta"









// CREATE ADDITIONAL VARIABLES
* Authors note: Here we add earnings income rank. We also create dichotomous variables. The saved dataset is the dataframe which we use for all analyses in the main document and appendix except figure A1 and A2 (see next section)
// link income rank
merge 1:1 shnro using  "$path2\income.dta", keepusing(rankimean45) keep(master match) nogen // income rank

// x y capped, categorized
gen parity = parity_stat
replace parity = 5 if parity_stat > 5

gen unions = forma_stat
replace unions = 5 if forma_stat > 5

gen marry = marry_stat
replace marry = 3 if marry_stat > 3

egen uniondurx2 = cut(uniondur), at(0,1,5,10,15,20,25,99)
egen marrydurx2 = cut(mardur),   at(0,1,5,10,15,20,25,99)
recode uniondurx2 (5 = 2) (10 = 3) (15 = 4) (20 = 5) (25 = 6)
recode marrydurx2 (5 = 2) (10 = 3) (15 = 4) (20 = 5) (25 = 6)

// income quartiles
egen inc4 = xtile(rankimean45), nq(4)

// drop if income measure is missing (0.09% of pop)
drop if inc4 == . 

keep shnro byear sex parity_stat forma_stat marry_stat rankimean45 parity unions marry inc4 uniondurx2 marrydurx2 mardur uniondur afb

compress
// save 
save "$path2\raw1b_rnr.dta", replace









// APPENDIX DATA 
* Authors note: Here for the index population (male 1963 cohort), link event-dates on births (chbyear) and partner id (spuhnro) and link birth date of partner to get partners age.

// take the male 63 cohort alive and not migrated by age 55, expand to 1 person 1 year format.
use shnro byear sex kuolv inpopsum svaltio_k using "persondata_wide.dta" if sex == 1 & svaltio_k == 1 & byear == 1963, clear
keep if inpopsum == 33
keep if kuolv == . 
drop kuolv inpopsum svaltio_k sex byear
preserve
expand 2018 - (1963+18) + 1
bys shnro: gen year = 1963+18 + _n - 1
save "temp.dta", replace
restore

// and link event-birth registers
merge 1:m shnro using  "biochildren_parents.dta", keep(match) keepusing(chbyear) nogen
ren chbyear year
gen birth = 1
duplicates drop shnro year, force
save "birth_temp.dta", replace

// and link partner id from 1987 (age from age 24 of the 63 cohort)
use "temp.dta", clear
merge 1:m shnro year using "men_union", keepusing(year spuhnro) keep(match master ) nogen
merge 1:1 shnro year using "birth_temp.dta", keepusing(year birth) keep(match master) nogen
ren shnro shnro_temp
ren spuhnro shnro

// and link partner id to partner birthyear information 
merge m:1 shnro using "persondata_wide.dta", keep(master match) keepusing(byear) nogen
ren  shnro spuhnro
ren  shnro_temp shnro
gen age = year - 1963
gen page = year - byear
recode birth . = 0
compress
save "raw1c.dta", replace




